
===========
Text2Speech
===========


Papers
------

* [1609] `WaveNet: A Generative Model for Raw Audio <https://arxiv.org/abs/1609.03499>`_
* [1702] `Deep Voice: Real-time Neural Text-to-Speech <https://arxiv.org/abs/1702.07825>`_
* [1702] `Char2Wav: End-to-End Speech Synthesis <http://josesotelo.com/speechsynthesis/>`_
* [1703] `Tacotron: Towards End-to-End Speech Synthesis <https://arxiv.org/abs/1703.10135>`_


Codes
-----

* `A TensorFlow implementation of DeepMind's WaveNet paper <https://github.com/ibab/tensorflow-wavenet>`_
* `RNN-based generative models for speech <https://github.com/sotelo/parrot>`_, implementation for paper < Char2Wav:
  End-to-End Speech Synthesis.>
* `tacotron <https://github.com/google/tacotron>`_, Audio samples from the paper "Tacotron: A Fully End-to-End
  Text-To-Speech Synthesis Model".


Frameworks
----------

* `MARY TTS <https://github.com/marytts/marytts>`_, an open-source, multilingual text-to-speech synthesis system
  written in pure java http://mary.dfki.de


